@@ -1,7 +1,14 @@
-#
-__version__ = '2.4.1'
+from pkg_resources import DistributionNotFound
+from pkg_resources import get_distribution
 
-from .hookspecs import hookspec, hookimpl  # noqa
+from .hookspecs import hookimpl
+from .hookspecs import hookspec
+
+try:
+    _full_version = get_distribution(__name__).version
+    __version__ = _full_version.split('+', 1)[0]
+except DistributionNotFound:
+    __version__ = '0.0.0.dev0'
 
 
 class exception:
@@ -9,12 +16,18 @@ class exception:
         def __str__(self):
             return "%s: %s" % (self.__class__.__name__, self.args[0])
 
+    class MissingSubstitution(Error):
+        FLAG = 'TOX_MISSING_SUBSTITUTION'
+        """placeholder for debugging configurations"""
+        def __init__(self, name):
+            self.name = name
+
     class ConfigError(Error):
         """ error in tox configuration. """
     class UnsupportedInterpreter(Error):
-        "signals an unsupported Interpreter"
+        """signals an unsupported Interpreter"""
     class InterpreterNotFound(Error):
-        "signals that an interpreter could not be found"
+        """signals that an interpreter could not be found"""
     class InvocationError(Error):
         """ an error while invoking a script. """
     class MissingFile(Error):
@@ -30,4 +43,7 @@ class exception:
             self.message = message
             super(exception.MinVersionError, self).__init__(message)
 
+
 from tox.session import main as cmdline  # noqa
+
+__all__ = ('hookspec', 'hookimpl', 'cmdline', 'exception', '__version__')
